"use strict";

var LayoutAlias = require('../../../../main/js/map/data/LayoutAlias');
var LayoutData = require('../../../../main/js/map/data/LayoutData');

var chai = require('chai');
var assert = chai.assert;

var logger = require('../../logger');

describe('LayoutData', function() {
  it("contructor", function() {
    var layoutId = 3;
    var name = "nm";
    var overlay = new LayoutData(layoutId, name);
    assert.equal(overlay.getId(), layoutId);
    assert.equal(overlay.getName(), name);
  });

  it("contructor from json obj", function() {
    var obj = {
      modelId : 15781,
      name : "test",
      description : "test",
      status : "OK",
      progress : "0.00",
      directory : "dir/subDir",
      creator : "admin ",
      inputDataAvailable : "true",
      idObject : 14852
    };
    var data = new LayoutData(obj);
    assert.ok(data);
    assert.equal(data.getInputDataAvailable(), true);
    assert.equal(data.getDirectory(), "dir/subDir");
  });

  it("contructor from prolematic json", function() {
    var obj = {
      modelId : 15781,
      name : "test",
      inputDataAvailable : "wtf",
      idObject : 14852
    };
    var data = new LayoutData(obj);
    assert.ok(data);
    assert.equal(logger.getWarnings().length, 1);
  });

  it("updateAlias", function() {
    var layoutId = 3;
    var name = "nm";
    var overlay = new LayoutData(layoutId, name);

    var aliasId = 4;
    var alias = new LayoutAlias({
      idObject : aliasId,
    });

    overlay.addAlias(alias);

    assert.equal(overlay.getAliasById(aliasId).getValue(), null);

    var val = 5;
    var alias2 = new LayoutAlias({
      idObject : aliasId,
      value : val,
    });
    overlay.updateAlias(alias2);

    assert.equal(overlay.getAliasById(aliasId).getValue(), val);

    assert.equal(logger.getWarnings().length, 0);
  });

  it("update invalid alias", function() {
    var layoutId = 3;
    var name = "nm";
    var overlay = new LayoutData(layoutId, name);

    var aliasId = 4;
    var alias = new LayoutAlias({
      idObject : aliasId,
    });

    overlay.updateAlias(alias);

    assert.equal(logger.getWarnings().length, 1);
  });
});
