"use strict";

var Helper = require('../../Helper');

var AbstractDbOverlay = require('../../../../main/js/map/overlay/AbstractDbOverlay');

var assert = require('assert');
var logger = require('../../logger');

describe('AbstractDbOverlay', function() {
  var helper;
  before(function() {
    helper = new Helper();
  });

  var mapMock = {
    registerSource : function() {
    },
    refreshInfoWindows : function() {
    },
    updateInfoWindowForIdentifiedElement : function() {
    },
  };

  it("constructor 1", function() {
    var oc = new AbstractDbOverlay({
      map : mapMock,
      name : 'test name'
    });
    assert.ok(oc);
    assert.equal(oc.getName(), 'test name');
    assert.equal(logger.getWarnings().length, 0);
  });

  it("constructor 2", function() {
    var oc = new AbstractDbOverlay({
      map : mapMock,
      name : 'test name',
      allowSearchById : true
    });
    assert.ok(oc);
    assert.ok(oc.allowSearchById());
  });

  it("constructor 3", function() {
    var oc = new AbstractDbOverlay({
      map : mapMock,
      name : 'test name',
      allowSearchById : false,
      allowGeneralSearch : true
    });
    assert.ok(oc);
    assert.ok(oc.allowGeneralSearch());
  });

  it("splitQuery", function() {
    var map = helper.createCustomMap();

    var oc = helper.createSearchDbOverlay(map);

    var result = oc.splitQuery("test q");
    assert.equal(result[0], "test q");
  });

  it("splitQuery 2", function() {
    var map = helper.createCustomMap();

    var oc = helper.createSearchDbOverlay(map);

    var result = oc.splitQuery("test,q");
    assert.equal(result[0], "test");
    assert.equal(result[1], "q");
  });

  it("splitQuery 3", function() {
    var map = helper.createCustomMap();

    var oc = helper.createSearchDbOverlay(map);

    var result = oc.splitQuery("test;q");
    assert.equal(result[0], "test");
    assert.equal(result[1], "q");
  });

  it("splitQuery 4", function() {
    var map = helper.createCustomMap();

    var oc = helper.createSearchDbOverlay(map);

    var result = oc.splitQuery("test;q,bla");
    assert.equal(result[0], "test");
    assert.equal(result[1], "q,bla");
    assert.equal(result.length, 2);
  });

  it("splitQuery 5", function() {
    var map = helper.createCustomMap();

    var oc = helper.createSearchDbOverlay(map);

    var result = oc.splitQuery("test;q,bla", true);
    assert.equal(result[0], "test");
    assert.equal(result[1], "q,bla");
    assert.equal(result[2], "test;q,bla");
  });
});
