"use strict";

var Helper = require('../../Helper');

var logger = require('../../logger');

var IdentifiedElement = require('../../../../main/js/map/data/IdentifiedElement');
var DrugDbOverlay = require('../../../../main/js/map/overlay/DrugDbOverlay');

var assert = require('assert');

describe('DrugDbOverlay', function() {
  var helper;
  before(function() {
    helper = new Helper();
  });

  it("constructor 1", function() {
    var map = helper.createCustomMap();
    var oc = new DrugDbOverlay({
      map : map,
      name : 'drug'
    });
    assert.ok(oc);
    assert.equal(oc.getName(), 'drug');

    assert.equal(logger.getWarnings.length, 0);
  });

  it("searchByQuery", function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var searchDb = helper.createDrugDbOverlay(map);
    return searchDb.searchByQuery("NADH").then(function(drugs) {
      assert.equal(drugs.length, 1);
      assert.equal(searchDb.getQueries().length, 1);
      return searchDb.getElementsByQuery(searchDb.getQueries()[0]);
    }).then(function(elements) {
      assert.ok(elements.length>1);
      return searchDb.getIdentifiedElements();
    }).then(function(elements) {
      assert.equal(elements.length, 1);
    });
  });

  it("searchNamesByTarget", function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var searchDb = helper.createDrugDbOverlay(map);

    var target = new IdentifiedElement({
      type : "ALIAS",
      id : 329170,
      modelId : 15781,
    });

    return searchDb.searchNamesByTarget(target).then(function(drugNames) {
      assert.equal(drugNames.length, 1);
      assert.equal(drugNames[0], "NADH");
    });
  });

});
